#define MFBIMAGEGLYPHBLT xf1bppImageGlyphBltWhite
#define OPEQ |=
#include "mfbmap.h"
#include "../../../mfb/mfbimggblt.c"
